@@ -39,13 +39,10 @@
 
 #include "gedit-document-saver.h"
 #include "gedit-debug.h"
-#include "gedit-convert.h"
 #include "gedit-prefs-manager.h"
 #include "gedit-marshal.h"
 #include "gedit-utils.h"
 #include "gedit-enum-types.h"
-
-#include "gedit-local-document-saver.h"
 #include "gedit-gio-document-saver.h"
 
 G_DEFINE_ABSTRACT_TYPE(GeditDocumentSaver, gedit_document_saver, G_TYPE_OBJECT)
@@ -141,7 +138,6 @@ gedit_document_saver_finalize (GObject *object)
 	GeditDocumentSaver *saver = GEDIT_DOCUMENT_SAVER (object);
 
 	g_free (saver->uri);
-	g_free (saver->backup_ext);
 
 	G_OBJECT_CLASS (gedit_document_saver_parent_class)->finalize (object);
 }
@@ -269,181 +265,6 @@ gedit_document_saver_new (GeditDocument           *doc,
 	return saver;
 }
 
-gchar *
-gedit_document_saver_get_end_newline (GeditDocumentSaver *saver,
-				      gsize 	         *len)
-{
-	gchar *n_buffer = NULL;
-	gsize n_len = 0;
-
-	if (saver->encoding != gedit_encoding_get_utf8 ())
-	{
-		n_buffer = gedit_convert_from_utf8 ("\n", 
-						    -1, 
-						    saver->encoding, 
-						    &n_len, 
-						    NULL);
-
-		if (n_buffer == NULL)
-		{
-			/* we do not error out for this */
-			g_warning ("Cannot convert '\\n' to the desired encoding.");
-		}
-	}
-	else
-	{
-		n_buffer = g_strdup ("\n");
-		n_len = 1;
-	}
-
-	*len = n_len;
-	return n_buffer;
-}
-
-/* FIXME: we should rework the code to not need to fetch the
-   whole buffer in memory. Also encoding conversion should
-   be done in chunks */
-gchar *
-gedit_document_saver_get_document_contents (GeditDocumentSaver *saver,
-					    gsize 	       *len,
-					    GError 	      **error)
-{
-	GtkTextBuffer *buffer = GTK_TEXT_BUFFER (saver->document);
-	GtkTextIter start_iter;
-	GtkTextIter end_iter;
-	gchar *contents;
-	
-	gtk_text_buffer_get_bounds (buffer, &start_iter, &end_iter);
-	contents = gtk_text_buffer_get_slice (buffer, &start_iter, &end_iter, TRUE);
-
-	*len = strlen (contents);
-
-	if (saver->encoding != gedit_encoding_get_utf8 ())
-	{
-		gchar *converted_contents;
-		gsize new_len;
-
-		converted_contents = gedit_convert_from_utf8 (contents, 
-							      *len, 
-							      saver->encoding,
-							      &new_len,
-							      error);
-		g_free (contents);
-
-		if (*error != NULL)
-		{
-			/* Conversion error */
-			return NULL;
-		}
-		else
-		{
-			contents = converted_contents;
-			*len = new_len;
-		}
-	}
-	
-	return contents;
-}
-
-/*
- * Write the document contents in fd.
- */
-gboolean
-gedit_document_saver_write_document_contents (GeditDocumentSaver  *saver,
-					      gint                 fd,
-					      GError             **error)
-{
-	gsize len;
-	gssize written;
-	gboolean res;
-	gchar *contents;
-
-	gedit_debug (DEBUG_SAVER);
-
-	contents = gedit_document_saver_get_document_contents (saver, &len, error);
-
-	/* make sure we are at the start */
-	res = (lseek (fd, 0, SEEK_SET) != -1);
-
-	/* Truncate the file to 0, in case it was not empty */
-	if (res)
-	{
-		res = (ftruncate (fd, 0) == 0);
-	}
-
-	/* Save the file content */
-	if (len > 0)
-	{
-		if (res)
-		{
-			const gchar *write_buffer = contents;
-			gssize to_write = len;
-
-			do
-			{
-				written = write (fd, write_buffer, to_write);
-				if (written == -1)
-				{
-					if (errno == EINTR)
-						continue;
-
-					res = FALSE;
-
-					break;
-				}
-
-				to_write -= written;
-				write_buffer += written;
-			}
-			while (to_write > 0);
-		}
-
-		/* make sure files are always terminated with \n (see bug #95676). Note
-		   that we strip the trailing \n when loading the file */
-		if (res)
-		{
-			gchar *n_buf;
-			gsize n_len;
-
-			n_buf = gedit_document_saver_get_end_newline (saver, &n_len);
-			if (n_buf != NULL)
-			{
-				written = write (fd, n_buf, n_len);
-				res = (written != -1 && (gsize) written == n_len);
-				g_free (n_buf);
-			}
-			else
-			{
-				g_warning ("Cannot add '\\n' at the end of the file.");
-			}
-		}
-	}
-
-#ifdef HAVE_FSYNC
-	/* Ensure that all the data reaches disk */
-	if (res && fsync (fd) != 0)
-	{
-		g_set_error (error,
-			     G_IO_ERROR,
-			     g_io_error_from_errno (errno),
-			     "%s", g_strerror (errno));
-		res = FALSE;
-	}
-#endif
-
-	if (!res)
-	{
-		g_set_error (error,
-			     G_IO_ERROR,
-			     g_io_error_from_errno (errno),
-			     "%s", g_strerror (errno));
-	}
-
-	g_free (contents);
-
-	return res;
-}
-
 void
 gedit_document_saver_saving (GeditDocumentSaver *saver,
 			     gboolean            completed,
@@ -487,18 +308,12 @@ gedit_document_saver_save (GeditDocumentSaver     *saver,
 	// report async (in an idle handler) or sync (bool ret)
 	// async is extra work here, sync is special casing in the caller
 
-	/* fetch saving options */
-	saver->backup_ext = gedit_prefs_manager_get_backup_extension ();
-
 	/* never keep backup of autosaves */
 	if ((saver->flags & GEDIT_DOCUMENT_SAVE_PRESERVE_BACKUP) != 0)
 		saver->keep_backup = FALSE;
 	else
 		saver->keep_backup = gedit_prefs_manager_get_create_backup_copy ();
 
-	/* TODO: add support for configurable backup dir */
-	saver->backups_in_curr_dir = TRUE;
-
 	GEDIT_DOCUMENT_SAVER_GET_CLASS (saver)->save (saver, old_mtime);
 }
 
